@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # Usage: ./benchmarks.sh <argument>
 #  where <argument> is a substring pattern of the benchmark name.
@@ -6,7 +6,7 @@
 #  if <argument> is omitted, all benchmarks are executed.
 #
 #  if <argument> is "reset", the benchmark data will be downloaded and prepared again.
-#   though the results/benchmark_results.csv and resutls/run_info_history.tsv historical
+#   though the results/benchmark_results.csv and results/run_info_history.tsv historical
 #   archives will be preserved.
 #  if <argument> is "clean", temporary files will be deleted.
 #  if <argument> is "setup", setup and install all the required tools.
@@ -24,8 +24,8 @@
 # Make sure you're using a release-optimized `qsv`.
 # If you can't use the prebuilt binaries at https://github.com/dathere/qsv/releases/latest,
 # build it to have at least the apply, geocode, luau, to and polars features enabled:
-# i.e. `cargo build --release --locked -F feature_capable,apply,geocode,luau,to,polars` or
-# `cargo install --locked qsv -F feature_capable,apply,geocode,luau,to,polars`
+# `CARGO_BUILD_RUSTFLAGS='-C target-cpu=native' cargo build --release --locked -F feature_capable,apply,geocode,luau,to,polars` or
+# `CARGO_BUILD_RUSTFLAGS='-C target-cpu=native' cargo install --locked qsv -F feature_capable,apply,geocode,luau,to,polars`
 #
 # This shell script has been tested on Linux and macOS. It should work on other Unix-like systems,
 # but will NOT run on native Windows. If you're on Windows, you can run it using Cygwin or WSL
@@ -42,7 +42,7 @@
 arg_pat="$1"
 
 # the version of this script
-bm_version=6.2.0
+bm_version=6.6.0
 
 # CONFIGURABLE VARIABLES ---------------------------------------
 # change as needed to reflect your environment/workloads
@@ -62,7 +62,7 @@ datazip=NYC_311_SR_2010-2020-sample-1M.7z
 # where to store the benchmark data
 data=NYC_311_SR_2010-2020-sample-1M.csv
 
-# Hyoerfine options - run `hyperfine --help`` for more info
+# Hyperfine options - run `hyperfine --help`` for more info
 # number of warmup runs for each benchmark.  A minimum of 2 is recommended
 warmup_runs=2
 # number of benchmark runs for each benchmark. A minimum of 3 is recommended
@@ -109,10 +109,10 @@ fi
 
 # check if required tools/dependencies are installed ---------
 
-# check if benchmarker_bin has the apply feature enabled
-if [[ "$benchmarker_version" != *"apply;"* ]]; then
-  echo "ERROR: $qsv_benchmarker_bin does not have the apply feature enabled."
-  echo "The qsv apply command is needed to format the benchmarks results."
+  # check if benchmarker_bin has the apply feature enabled
+  if [[ "$benchmarker_version" != *"apply;"* ]]; then
+    echo "ERROR: $qsv_benchmarker_bin does not have the apply feature enabled."
+    echo "The qsv apply command is needed to format the benchmarks results."
   exit
 fi
 
@@ -176,7 +176,7 @@ if [[ "$arg_pat" == "setup" ]]; then
   fi
 
   # if all required tools are installed, exit
-  if [[ "$need_sevenz" -eq 0 && "$need_hyperfine" -eq 0 && "$need_awk" -eq 0 && "$need_sed" -eq 0 ]]; then
+  if [[ "$need_sevenz" -eq 0 && "$need_hyperfine" -eq 0 && "$need_awk" -eq 0 && "$need_sed" -eq 0 && "$need_duckdb" -eq 0 ]]; then
     echo "> All required tools are installed..."
     exit
   fi
@@ -184,8 +184,22 @@ if [[ "$arg_pat" == "setup" ]]; then
   # check if homebrew is installed, if not, install it
   # as we need it to install the required tools
   if ! command -v brew &>/dev/null; then
-    echo "INFO: Homebrew could not be found. Installing brew first. Please enter requested info when prompted."
-    curl -fsSL "https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh"
+    echo -n "INFO: Homebrew could not be found. Do you wish to install? "
+    read -p '(Requires sudo) (y/n)? ' -r CHOICE
+    case "$CHOICE" in
+    y | Y)
+      echo "Installing brew. Please enter requested info when prompted."
+      bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh)"
+      ;;
+    n | N)
+      echo "Not installing brew. Review https://brew.sh/"
+      exit
+      ;;
+    *)
+      echo 'Invalid entry (only y/n)'
+      exit
+      ;;
+    esac
   fi
 
   # if 7z is not installed, install it
@@ -510,9 +524,9 @@ run fmt_no_final_newline "$qsv_bin" fmt --no-final-newline "$data"
 run foreach "$qsv_bin" foreach City "echo {}" "$data"
 run frequency "$qsv_bin" frequency "$data"
 run --index frequency_index "$qsv_bin" frequency "$data"
-run --index frequency_index_stats_mode_auto "$qsv_bin" frequency --stats-mode auto "$data"
-run --index frequency_index_stats_mode_force "$qsv_bin" frequency --stats-mode force "$data"
-run --index frequency_index_stats_mode_none "$qsv_bin" frequency --stats-mode none "$data"
+run --index frequency_index_stats_mode_auto env QSV_STATS_MODE=auto bash -c \'"$qsv_bin" frequency "$data"\'
+run --index frequency_index_stats_mode_force env QSV_STATS_MODE=force bash -c \'"$qsv_bin" frequency "$data"\'
+run --index frequency_index_stats_mode_none env QSV_STATS_MODE=none bash -c \'"$qsv_bin" frequency "$data"\'
 run frequency_no_limit "$qsv_bin" frequency --limit 0 "$data"
 run --index frequency_no_limit_index "$qsv_bin" frequency --limit 0 "$data"
 run frequency_other_sorted "$qsv_bin" frequency --other-sorted "$data"
@@ -553,6 +567,7 @@ run luau_filter_no_globals_no_colidx "$qsv_bin" luau filter --no-globals \"Locat
 run luau_multi_no_globals "$qsv_bin" luau map dow,hourday,weekno --no-globals "file:dt_format.luau" "$data"
 run luau_multi_no_globals_colidx "$qsv_bin" luau map dow,hourday,weekno --no-globals --colindex "file:dt_format.luau" "$data"
 run luau_script "$qsv_bin" luau map turnaround_time "file:turnaround_time.luau" "$data"
+run luau_script_debug env QSV_LOG_LEVEL=debug bash -c \'"$qsv_bin" luau map turnaround_time "file:turnaround_time.luau" "$data"\'
 run luau_script_colidx "$qsv_bin" luau map turnaround_time --colindex "file:turnaround_time.luau" "$data"
 run luau_script_no_globals "$qsv_bin" luau map turnaround_time --no-globals "file:turnaround_time.luau" "$data"
 run luau_script_no_globals_colidx "$qsv_bin" luau map turnaround_time --no-globals --colindex "file:turnaround_time.luau" "$data"
@@ -662,8 +677,8 @@ run --index stats_everything_index_j1_with_cache "$qsv_bin" stats "$data" --ever
 run --index stats_everything_sorted_index "$qsv_bin" stats data_sorted.csv --force --everything
 run --index stats_everything_sorted_index_with_cache "$qsv_bin" stats data_sorted.csv --everything --cache-threshold 1
 run table "$qsv_bin" table "$data"
-run template "$qsv_bin" template --template-file template.tpl "$data" > /dev/null
-run template_lookup_outdir "$qsv_bin" template --template-file template-with-cb-lookup.tpl "$data" > /dev/null
+run template "$qsv_bin" template --template-file template.tpl "$data" >/dev/null
+run template_lookup_outdir "$qsv_bin" template --template-file template-with-cb-lookup.tpl "$data" >/dev/null
 run to_xlsx "$qsv_bin" to xlsx benchmark_work.xlsx "$data"
 run to_sqlite "$qsv_bin" to sqlite benchmark_work.db "$data"
 run to_datapackage "$qsv_bin" to datapackage benchmark_work.json "$data"
