@@ -98,7 +98,7 @@ pub mod sqlp;
 pub mod stats;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 pub mod table;
-#[cfg(feature = "feature_capable")]
+#[cfg(any(feature = "feature_capable", feature = "datapusher_plus"))]
 pub mod template;
 #[cfg(all(feature = "to", feature = "feature_capable"))]
 pub mod to;
