@@ -164,11 +164,11 @@ const WHITESPACE_MARKERS: &[(char, &str)] = &[
 /// ```
 /// let s = "hello\tworld\n";
 /// let vis = visualize_whitespace(s);
-/// assert_eq!(vis, "hello《→》world《¶》");
+/// similar_asserts::assert_eq!(vis, "hello《→》world《¶》");
 ///
 /// let spaces = "   ";
 /// let vis = visualize_whitespace(spaces);
-/// assert_eq!(vis, "《_》《_》《_》");
+/// similar_asserts::assert_eq!(vis, "《_》《_》《_》");
 /// ```
 pub fn visualize_whitespace(s: &str) -> String {
     // Check if string is all spaces
@@ -2181,31 +2181,34 @@ pub fn get_stats_records(
     // otherwise, run stats command to generate stats.csv.data.jsonl file
     if !stats_data_loaded {
         let stats_args = crate::cmd::stats::Args {
-            arg_input:            args.arg_input.as_ref().map(String::from),
-            flag_select:          crate::select::SelectColumns::parse("").unwrap(),
-            flag_everything:      false,
-            flag_typesonly:       false,
-            flag_infer_boolean:   false,
-            flag_mode:            false,
-            flag_cardinality:     true,
-            flag_median:          false,
-            flag_quartiles:       false,
-            flag_mad:             false,
-            flag_nulls:           false,
-            flag_round:           4,
-            flag_infer_dates:     true,
-            flag_dates_whitelist: args.flag_dates_whitelist.to_string(),
-            flag_prefer_dmy:      args.flag_prefer_dmy,
-            flag_force:           args.flag_force,
-            flag_jobs:            Some(njobs(args.flag_jobs)),
-            flag_stats_jsonl:     true,
-            flag_cache_threshold: 1, // force the creation of stats cache files
-            flag_output:          None,
-            flag_no_headers:      args.flag_no_headers,
-            flag_delimiter:       args.flag_delimiter,
-            flag_memcheck:        args.flag_memcheck,
-            flag_vis_whitespace:  false,
-            flag_dataset_stats:   true,
+            arg_input:             args.arg_input.as_ref().map(String::from),
+            flag_select:           crate::select::SelectColumns::parse("").unwrap(),
+            flag_everything:       false,
+            flag_typesonly:        false,
+            flag_infer_boolean:    false,
+            flag_boolean_patterns: String::new(),
+            flag_mode:             false,
+            flag_cardinality:      true,
+            flag_median:           false,
+            flag_quartiles:        false,
+            flag_mad:              false,
+            flag_percentiles:      false,
+            flag_percentile_list:  "5,10,40,60,90,95".to_string(),
+            flag_nulls:            false,
+            flag_round:            4,
+            flag_infer_dates:      true,
+            flag_dates_whitelist:  args.flag_dates_whitelist.to_string(),
+            flag_prefer_dmy:       args.flag_prefer_dmy,
+            flag_force:            args.flag_force,
+            flag_jobs:             Some(njobs(args.flag_jobs)),
+            flag_stats_jsonl:      true,
+            flag_cache_threshold:  1, // force the creation of stats cache files
+            flag_output:           None,
+            flag_no_headers:       args.flag_no_headers,
+            flag_delimiter:        args.flag_delimiter,
+            flag_memcheck:         args.flag_memcheck,
+            flag_vis_whitespace:   false,
+            flag_dataset_stats:    true,
         };
 
         let tempfile = tempfile::Builder::new()
