@@ -14,7 +14,7 @@ fn applydp_ops_unknown_operation() {
         .arg("data.csv");
 
     let got: String = wrk.output_stderr(&mut cmd);
-    assert_eq!(&*got, "usage error: Unknown 'obfuscate' operation\n")
+    similar_asserts::assert_eq!(&*got, "usage error: Unknown 'obfuscate' operation\n")
 }
 
 #[test]
@@ -44,7 +44,7 @@ fn applydp_ops_upper() {
         svec!["SUE", "BIRD"],
         svec!["HOPKINS", "JADE"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -74,7 +74,7 @@ fn applydp_ops_escape() {
         svec!["Sue", "Bird\\u{1f426}"],
         svec!["Hop\\u{119}kins", "J\\u{e6}de"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -106,7 +106,7 @@ fn applydp_ops_upper_rename() {
         svec!["SUE", "BIRD"],
         svec!["HOPKINS", "JADE"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -131,7 +131,7 @@ fn applydp_ops_upper_rename_invalid() {
         .arg("data.csv");
 
     let got: String = wrk.output_stderr(&mut cmd);
-    assert_eq!(
+    similar_asserts::assert_eq!(
         got,
         "usage error: Number of new columns does not match input column selection.\n"
     );
@@ -166,7 +166,7 @@ fn applydp_ops_upper_index_params() {
         svec!["SUE", "BIRD"],
         svec!["HOPKINS", "JADE"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -236,7 +236,7 @@ fn applydp_dynfmt() {
              strawberries, all 3 - is just worth it!"
         ],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -263,7 +263,7 @@ fn applydp_ops_empty_shortcircuit() {
         svec!["0"],
         svec!["7"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -299,7 +299,7 @@ fn applydp_ops_replace() {
         svec!["Mr. Brown is not pleased."],
         svec!["this is a silverado car"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -322,7 +322,7 @@ fn applydp_ops_replace_validation_error() {
         .arg("data.csv");
 
     let got = wrk.output_stderr(&mut cmd);
-    assert_eq!(
+    similar_asserts::assert_eq!(
         got,
         "usage error: --comparand (-C) and --replacement (-R) are required for replace \
          operation.\n"
@@ -363,7 +363,7 @@ fn applydp_ops_regex_replace() {
         svec!["Won't fall for that scam!"],
         svec!["Just enter SSN when prompted. Also try SSN if it doesn't work."],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -395,7 +395,7 @@ fn applydp_regex_replace_issue1469() {
         svec!["Gordon", "H", "Irvin"],
         svec!["Jack", "K", "Lynch"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -418,7 +418,7 @@ fn applydp_ops_regex_replace_validation_error() {
         .arg("data.csv");
 
     let got = wrk.output_stderr(&mut cmd);
-    assert_eq!(
+    similar_asserts::assert_eq!(
         got,
         "usage error: --comparand (-C) and --replacement (-R) are required for regex_replace \
          operation.\n"
@@ -487,7 +487,7 @@ fn applydp_ops_mtrim() {
         svec!["Embedded (((multiple parens"],
         svec!["reverse parens"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -525,7 +525,7 @@ fn applydp_ops_round() {
         svec!["5"],
         svec!["not a number, should be ignored"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -566,7 +566,7 @@ fn applydp_ops_round_5places() {
         svec!["5"],
         svec!["not a number, should be ignored"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -596,7 +596,7 @@ fn applydp_ops_chain() {
         svec!["MARY SUE"],
         svec!["HOPKINS"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -617,7 +617,7 @@ fn applydp_ops_chain_validation_error() {
         .arg("data.csv");
 
     let got = wrk.output_stderr(&mut cmd);
-    assert_eq!(
+    similar_asserts::assert_eq!(
         got,
         "usage error: you can only use copy(0), regex_replace(0), replace(0), and strip(2) ONCE \
          per operation series.\n"
@@ -641,7 +641,7 @@ fn applydp_ops_chain_validation_error_missing_comparand() {
         .arg("data.csv");
 
     let got = wrk.output_stderr(&mut cmd);
-    assert_eq!(
+    similar_asserts::assert_eq!(
         got,
         "usage error: --comparand (-C) is required for strip operations.\n"
     );
@@ -675,7 +675,7 @@ fn applydp_ops_chain_squeeze0() {
         svec!["MARYSUE"],
         svec!["HOPKINS"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -705,7 +705,7 @@ fn applydp_ops_squeeze0() {
         svec!["MarySue"],
         svec!["JohnHopkins"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -737,7 +737,7 @@ fn applydp_ops_chain_strip() {
         svec!["MARY SUE"],
         svec!["HOPKINS"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -767,7 +767,7 @@ fn applydp_ops_mixed_case_chain() {
         svec!["MARY SUE"],
         svec!["HOPKINS"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -791,7 +791,7 @@ fn applydp_no_headers() {
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![svec!["JOHN"], svec!["MARY"], svec!["SUE"], svec!["HOPKINS"]];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -823,7 +823,7 @@ fn applydp_rename() {
         svec!["SUE"],
         svec!["HOPKINS"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -855,7 +855,7 @@ fn applydp_new_column() {
         svec!["Sue", "SUE"],
         svec!["Hopkins", "HOPKINS"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -886,7 +886,7 @@ fn applydp_emptyreplace() {
         svec!["Sue"],
         svec!["Hopkins"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -917,7 +917,7 @@ fn apply_emptyreplace_multiple_columns() {
         svec!["Sue", "NA", "Boston"],
         svec!["Hopkins", "40", "NA"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -948,391 +948,5 @@ fn apply_emptyreplace_all_columns() {
         svec!["Sue", "NA", "Boston"],
         svec!["Hopkins", "40", "NA"],
     ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt() {
-    let wrk = Workdir::new("applydp");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date"],
-            svec!["September 17, 2012 10:09am EST"],
-            svec!["Wed, 02 Jun 2021 06:31:39 GMT"],
-            svec!["2009-01-20 05:00 EST"],
-            svec!["July 4, 2005"],
-            svec!["2021-05-01T01:17:02.604456Z"],
-            svec!["This is not a date and it will not be reformatted"],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt").arg("Created Date").arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date"],
-        svec!["2012-09-17T15:09:00+00:00"],
-        svec!["2021-06-02T06:31:39+00:00"],
-        svec!["2009-01-20T10:00:00+00:00"],
-        svec!["2005-07-04"],
-        svec!["2021-05-01T01:17:02.604456+00:00"],
-        svec!["This is not a date and it will not be reformatted"],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_keep_zero_time() {
-    let wrk = Workdir::new("applydp");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date"],
-            svec!["September 17, 2012 10:09am EST"],
-            svec!["Wed, 02 Jun 2021 06:31:39 GMT"],
-            svec!["2009-01-20 05:00 EST"],
-            svec!["July 4, 2005"],
-            svec!["2021-05-01T01:17:02.604456Z"],
-            svec!["This is not a date and it will not be reformatted"],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt")
-        .arg("Created Date")
-        .arg("--keep-zero-time")
-        .arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date"],
-        svec!["2012-09-17T15:09:00+00:00"],
-        svec!["2021-06-02T06:31:39+00:00"],
-        svec!["2009-01-20T10:00:00+00:00"],
-        svec!["2005-07-04T00:00:00+00:00"],
-        svec!["2021-05-01T01:17:02.604456+00:00"],
-        svec!["This is not a date and it will not be reformatted"],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_multiple_cols() {
-    let wrk = Workdir::new("applydp");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date", "End Date"],
-            svec![
-                "September 17, 2012 10:09am EST",
-                "September 18, 2012 10:09am EST"
-            ],
-            svec![
-                "Wed, 02 Jun 2021 06:31:39 GMT",
-                "Wed, 02 Jun 2021 08:31:39 GMT"
-            ],
-            svec!["2009-01-20 05:00 EST", "2009-01-21 05:00 EST"],
-            svec!["July 4, 2005", "July 5, 2005"],
-            svec!["2021-05-01T01:17:02.604456Z", "2021-05-02T01:17:02.604456Z"],
-            svec![
-                "This is not a date and it will not be reformatted",
-                "This is not a date and it will not be reformatted"
-            ],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt")
-        .arg("Created Date,End Date")
-        .arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date", "End Date"],
-        svec!["2012-09-17T15:09:00+00:00", "2012-09-18T15:09:00+00:00"],
-        svec!["2021-06-02T06:31:39+00:00", "2021-06-02T08:31:39+00:00"],
-        svec!["2009-01-20T10:00:00+00:00", "2009-01-21T10:00:00+00:00"],
-        svec!["2005-07-04", "2005-07-05"],
-        svec![
-            "2021-05-01T01:17:02.604456+00:00",
-            "2021-05-02T01:17:02.604456+00:00"
-        ],
-        svec![
-            "This is not a date and it will not be reformatted",
-            "This is not a date and it will not be reformatted"
-        ],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_multiple_cols_keep_zero_time() {
-    let wrk = Workdir::new("applydp");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date", "End Date"],
-            svec![
-                "September 17, 2012 10:09am EST",
-                "September 18, 2012 10:09am EST"
-            ],
-            svec![
-                "Wed, 02 Jun 2021 06:31:39 GMT",
-                "Wed, 02 Jun 2021 08:31:39 GMT"
-            ],
-            svec!["2009-01-20 05:00 EST", "2009-01-21 05:00 EST"],
-            svec!["July 4, 2005", "July 5, 2005"],
-            svec!["2021-05-01T01:17:02.604456Z", "2021-05-02T01:17:02.604456Z"],
-            svec![
-                "This is not a date and it will not be reformatted",
-                "This is not a date and it will not be reformatted"
-            ],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt")
-        .arg("Created Date,End Date")
-        .arg("--keep-zero-time")
-        .arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date", "End Date"],
-        svec!["2012-09-17T15:09:00+00:00", "2012-09-18T15:09:00+00:00"],
-        svec!["2021-06-02T06:31:39+00:00", "2021-06-02T08:31:39+00:00"],
-        svec!["2009-01-20T10:00:00+00:00", "2009-01-21T10:00:00+00:00"],
-        svec!["2005-07-04T00:00:00+00:00", "2005-07-05T00:00:00+00:00"],
-        svec![
-            "2021-05-01T01:17:02.604456+00:00",
-            "2021-05-02T01:17:02.604456+00:00"
-        ],
-        svec![
-            "This is not a date and it will not be reformatted",
-            "This is not a date and it will not be reformatted"
-        ],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_multiple_cols_rename() {
-    let wrk = Workdir::new("applydp");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date", "End Date"],
-            svec![
-                "September 17, 2012 10:09am EST",
-                "September 18, 2012 10:09am EST"
-            ],
-            svec![
-                "Wed, 02 Jun 2021 06:31:39 GMT",
-                "Wed, 02 Jun 2021 08:31:39 GMT"
-            ],
-            svec!["2009-01-20 05:00 EST", "2009-01-21 05:00 EST"],
-            svec!["July 4, 2005", "July 5, 2005"],
-            svec!["2021-05-01T01:17:02.604456Z", "2021-05-02T01:17:02.604456Z"],
-            svec![
-                "This is not a date and it will not be reformatted",
-                "This is not a date and it will not be reformatted"
-            ],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt")
-        .arg("Created Date,End Date")
-        .arg("--formatstr")
-        .arg("%u")
-        .arg("--rename")
-        .arg("Created Weekday,End Weekday")
-        .arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Weekday", "End Weekday"],
-        svec!["1", "2"],
-        svec!["3", "3"],
-        svec!["2", "3"],
-        svec!["1", "2"],
-        svec!["6", "7"],
-        svec![
-            "This is not a date and it will not be reformatted",
-            "This is not a date and it will not be reformatted"
-        ],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_prefer_dmy() {
-    let wrk = Workdir::new("apply_dmy");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date"],
-            svec!["September 17, 2012 10:09am EST"],
-            svec!["02/06/2021"],
-            svec!["2009-01-20 05:00 EST"],
-            svec!["July 4, 2005"],
-            svec!["2021-05-01T01:17:02.604456Z"],
-            svec!["10/05/71"],
-            svec!["12/31/71"],
-            svec!["This is not a date and it will not be reformatted"],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt")
-        .arg("Created Date")
-        .arg("--prefer-dmy")
-        .arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date"],
-        svec!["2012-09-17T15:09:00+00:00"],
-        svec!["2021-06-02"],
-        svec!["2009-01-20T10:00:00+00:00"],
-        svec!["2005-07-04"],
-        svec!["2021-05-01T01:17:02.604456+00:00"],
-        svec!["1971-05-10"],
-        svec!["1971-12-31"], /* will still parse obviously valid mdy dates that are not valid as
-                              * dmy */
-        svec!["This is not a date and it will not be reformatted"],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_prefer_dmy_env() {
-    let wrk = Workdir::new("apply_prefer_dmy_env");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date"],
-            svec!["September 17, 2012 10:09am EST"],
-            svec!["02/06/2021"],
-            svec!["2009-01-20 05:00 EST"],
-            svec!["July 4, 2005"],
-            svec!["2021-05-01T01:17:02.604456Z"],
-            svec!["10/05/71"],
-            svec!["12/31/71"],
-            svec!["This is not a date and it will not be reformatted"],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.env("QSV_PREFER_DMY", "1");
-    cmd.arg("datefmt").arg("Created Date").arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date"],
-        svec!["2012-09-17T15:09:00+00:00"],
-        svec!["2021-06-02"],
-        svec!["2009-01-20T10:00:00+00:00"],
-        svec!["2005-07-04"],
-        svec!["2021-05-01T01:17:02.604456+00:00"],
-        svec!["1971-05-10"],
-        svec!["1971-12-31"], /* will still parse obviously valid mdy dates that are not valid as
-                              * dmy */
-        svec!["This is not a date and it will not be reformatted"],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_fmtstring() {
-    let wrk = Workdir::new("applydp");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date"],
-            svec!["September 17, 2012 10:09am EST"],
-            svec!["Wed, 02 Jun 2021 06:31:39 GMT"],
-            svec!["2009-01-20 05:00 EST"],
-            svec!["2015-09-30 18:48:56.35272715 UTC"],
-            svec!["This is not a date and it will not be reformatted"],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt")
-        .arg("Created Date")
-        .arg("--formatstr")
-        .arg("%a %b %e %T %Y %z")
-        .arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date"],
-        svec!["Mon Sep 17 15:09:00 2012 +0000"],
-        svec!["Wed Jun  2 06:31:39 2021 +0000"],
-        svec!["Tue Jan 20 10:00:00 2009 +0000"],
-        svec!["Wed Sep 30 18:48:56 2015 +0000"],
-        svec!["This is not a date and it will not be reformatted"],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_fmtstring_with_literals() {
-    let wrk = Workdir::new("applydp");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date"],
-            svec!["September 17, 2012 10:09am EST"],
-            svec!["Wed, 02 Jun 2021 06:31:39 GMT"],
-            svec!["2009-01-20 05:00 EST"],
-            svec!["2015-09-30 18:48:56.35272715 UTC"],
-            svec!["This is not a date and it will not be reformatted"],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt")
-        .arg("Created Date")
-        .arg("--formatstr")
-        .arg("%c is day %j, week %V of %G")
-        .arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date"],
-        svec!["Mon Sep 17 15:09:00 2012 is day 261, week 38 of 2012"],
-        svec!["Wed Jun  2 06:31:39 2021 is day 153, week 22 of 2021"],
-        svec!["Tue Jan 20 10:00:00 2009 is day 020, week 04 of 2009"],
-        svec!["Wed Sep 30 18:48:56 2015 is day 273, week 40 of 2015"],
-        svec!["This is not a date and it will not be reformatted"],
-    ];
-    assert_eq!(got, expected);
-}
-
-#[test]
-fn applydp_datefmt_fmtstring_notime() {
-    let wrk = Workdir::new("applydp");
-    wrk.create(
-        "data.csv",
-        vec![
-            svec!["Created Date"],
-            svec!["September 17, 2012 10:09am EST"],
-            svec!["Wed, 02 Jun 2021 06:31:39 GMT"],
-            svec!["2009-01-20 05:00 EST"],
-            svec!["4/8/2014 14:13"],
-            svec!["This is not a date and it will not be reformatted"],
-        ],
-    );
-    let mut cmd = wrk.command("applydp");
-    cmd.arg("datefmt")
-        .arg("Created Date")
-        .arg("--formatstr")
-        .arg("%Y-%m-%d")
-        .arg("data.csv");
-
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["Created Date"],
-        svec!["2012-09-17"],
-        svec!["2021-06-02"],
-        svec!["2009-01-20"],
-        svec!["2014-04-08"],
-        svec!["This is not a date and it will not be reformatted"],
-    ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
