@@ -41,7 +41,7 @@ fn combo_sort_dedup() {
         svec!["5", "2021-04-26 19:29:26", "f"],
         svec!["2", "2021-04-26 20:22:26", "e"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 
     wrk.create("in2.csv", expected);
 
@@ -58,7 +58,7 @@ fn combo_sort_dedup() {
         svec!["5", "2021-04-26 19:29:26", "f"],
         svec!["60", "2021-04-26 04:52:46", "g"],
     ];
-    assert_eq!(got2, expected2);
+    similar_asserts::assert_eq!(got2, expected2);
 
     wrk.create("in3.csv", expected2);
 
@@ -75,24 +75,7 @@ fn combo_sort_dedup() {
         svec!["30", "2021-04-26 11:44:13", "c"],
         svec!["60", "2021-04-26 04:52:46", "g"],
     ];
-    assert_eq!(got3, expected3);
-}
-
-#[test]
-#[ignore = "Doesn't work on GH Action runners, but works locally. Ignoring so GH CI doesn't fail."]
-fn utf8_check_invalid() {
-    // this test runs properly locally, but the github action runners
-    // don't run it properly, as it seems the test files are not encoded properly
-    // by GitHub so we're ignoring it for CI to work.
-    let wrk = Workdir::new("utf8_check_invalid");
-
-    let nonutf8_file = wrk.load_test_file("test-windows1252.csv");
-
-    let mut cmd = wrk.command("headers");
-    cmd.arg(nonutf8_file);
-
-    let got: String = wrk.output_stderr(&mut cmd);
-    assert!(got.contains("is not UTF-8 encoded"));
+    similar_asserts::assert_eq!(got3, expected3);
 }
 
 #[test]
