@@ -24,7 +24,7 @@ fn dedup_normal() {
         svec!["2", "B"],
         svec!["2", "b"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -46,7 +46,7 @@ fn dedup_no_case() {
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![svec!["N", "S"], svec!["10", "a"], svec!["2", "B"]];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -71,7 +71,36 @@ fn dedup_issue_1381() {
         svec!["Member of Legislative Assembly"],
         svec!["Member of Tamil Nadu Legislative Assembly"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
+}
+
+#[test]
+fn dedup_issue_1665_numeric() {
+    let wrk = Workdir::new("dedup_issue_1665_numeric");
+    wrk.create(
+        "in.csv",
+        vec![
+            svec!["data"],
+            svec!["1"],
+            svec!["3"],
+            svec!["3"],
+            svec!["5"],
+            svec!["10"],
+        ],
+    );
+
+    let mut cmd = wrk.command("dedup");
+    cmd.arg("-N").arg("in.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["data"],
+        svec!["1"],
+        svec!["3"],
+        svec!["5"],
+        svec!["10"],
+    ];
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -93,7 +122,7 @@ fn dedup_select() {
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![svec!["N", "S"], svec!["10", "a"], svec!["2", "B"]];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -107,7 +136,7 @@ fn dedup_select_issue774() {
     let got: String = wrk.stdout(&mut cmd);
     let expected = wrk.load_test_resource("dedup-by-id-test-expected.csv");
 
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -140,7 +169,7 @@ fn dedup_sorted() {
         svec!["3", "c"],
         svec!["4", "d"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -176,7 +205,7 @@ fn dedup_sorted_nocase() {
         svec!["3", "c"],
         svec!["4", "d"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -212,7 +241,7 @@ fn dedup_alreadysorted_nocase() {
         svec!["3", "c"],
         svec!["4", "d"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
