@@ -22,7 +22,7 @@ fn extsort_linemode() {
     let expected_csv = wrk.load_test_resource("adur-public-toilets-sorted.csv");
     wrk.create_from_string("adur-public-toilets-sorted.csv", &expected_csv);
 
-    assert_eq!(dos2unix(&sorted_output), dos2unix(&expected_csv));
+    similar_asserts::assert_eq!(dos2unix(&sorted_output), dos2unix(&expected_csv));
 }
 
 #[test]
@@ -34,16 +34,12 @@ fn extsort_csvmode() {
     let unsorted_csv = wrk.load_test_resource("adur-public-toilets.csv");
     wrk.create_from_string("adur-public-toilets.csv", &unsorted_csv);
 
-    // set the environment variable to autoindex
-    std::env::set_var("QSV_AUTOINDEX_SIZE", "1");
-
     let mut cmd = wrk.command("extsort");
-    cmd.arg("adur-public-toilets.csv")
+    cmd.env("QSV_AUTOINDEX_SIZE", "1")
+        .arg("adur-public-toilets.csv")
         .args(["--select", "OpeningHours,StreetAddress,LocationText"])
         .arg("adur-public-toilets-extsort-csvmode.csv");
     wrk.output(&mut cmd);
-    // unset the environment variable
-    std::env::remove_var("QSV_AUTOINDEX_SIZE");
 
     // load sorted output
     let sorted_output: String = wrk.from_str(&wrk.path("adur-public-toilets-extsort-csvmode.csv"));
@@ -51,7 +47,7 @@ fn extsort_csvmode() {
     let expected_csv = wrk.load_test_resource("adur-public-toilets-extsorted-csvmode.csv");
     wrk.create_from_string("adur-public-toilets-extsorted-csvmode.csv", &expected_csv);
 
-    assert_eq!(dos2unix(&sorted_output), dos2unix(&expected_csv));
+    similar_asserts::assert_eq!(dos2unix(&sorted_output), dos2unix(&expected_csv));
 }
 
 #[test]
@@ -116,5 +112,5 @@ fn extsort_issue_2391() {
         svec!["272", "139284", "9730000630075"],
         svec!["273", "139285", "9730000630075"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
