@@ -18,7 +18,7 @@ fn test_input_comment() {
         svec!["d", "4", "delta"],
         svec!["e", "5", "epsilon"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -48,7 +48,7 @@ fn test_input_skiplines() {
         svec!["c", "3"],
         svec!["e", "5"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -66,7 +66,7 @@ fn test_input_autoskip() {
         svec!["a", "2", "z", "1.2020569"],
         svec!["c", "42", "x", "1.0"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -90,7 +90,7 @@ fn test_input_quotestyle_nonnumeric() {
 "a",1.0,1,"this is a string"
 "c",3.5,3,"this is another string"
 "e",3.14,42,"this is a third string""#;
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -113,7 +113,7 @@ fn test_input_quotestyle_necessary() {
 a,1.0,1,"1,234,5678 - number with commas"
 c,3.5,3,this is another string
 e,3.14,42,this is a third string"#;
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -136,7 +136,7 @@ fn test_input_quotestyle_all() {
 "a","1.0","1","1,234,5678 - number with commas"
 "c","3.5","3","this is another string"
 "e","3.14","42","this is a third string""#;
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -162,7 +162,7 @@ fn test_input_skip_one_line() {
         svec!["c", "3"],
         svec!["e", "5"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -187,7 +187,7 @@ fn test_input_skip_no_line() {
         svec!["c", "3"],
         svec!["e", "5"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -212,7 +212,7 @@ fn test_input_trim_headers() {
         svec!["c  ", "3"],
         svec!["e", "5   "],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -237,7 +237,7 @@ fn test_input_trim_fields() {
         svec!["c", "3"],
         svec!["e", "5"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -264,7 +264,7 @@ fn test_input_trim_headers_fields() {
         svec!["c", "3"],
         svec!["e", "5"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -291,7 +291,7 @@ fn test_input_skip_lastlines() {
         svec!["b", "2"],
         svec!["c", "3"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -324,7 +324,7 @@ fn test_input_skip_lines_both() {
         svec!["b", "2"],
         svec!["c", "3"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -347,7 +347,7 @@ fn test_input_both_skip_flexible() {
         svec!["b", "2"],
         svec!["c", "3"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -416,7 +416,7 @@ fn input_noheadertrim() {
             "OH"
         ],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -460,7 +460,9 @@ fn input_headertrim() {
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![
-        svec!["LatD", "LatM", "LatS", "NS", "LonD", "LonM", "LonS", "EW", "City", "State"],
+        svec![
+            "LatD", "LatM", "LatS", "NS", "LonD", "LonM", "LonS", "EW", "City", "State"
+        ],
         svec![
             "41",
             "5",
@@ -474,5 +476,5 @@ fn input_headertrim() {
             "OH"
         ],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
