@@ -27,7 +27,7 @@ fn py_map() {
         svec!["c", "72", "73"],
         svec!["d", "7", "8"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -57,7 +57,7 @@ fn py_map_error() {
         svec!["c", "72", "<ERROR>"],
         svec!["d", "7", "<ERROR>"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -87,7 +87,7 @@ fn py_map_builtins() {
         svec!["c", "72", "97"],
         svec!["d", "7", "32"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -117,7 +117,7 @@ fn py_map_math() {
         svec!["c", "72", "36"],
         svec!["d", "7", "3"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -147,7 +147,7 @@ fn py_map_datetime() {
         svec!["c", "1991-07-04", "1991-06-29"],
         svec!["d", "2021-01-04", "2020-12-30"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -215,7 +215,7 @@ def celsius_to_fahrenheit(celsius):
         svec!["d", "7", "13"],
         svec!["e", "fib of 8", "incorrect input - not a number"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 
     let mut cmd = wrk.command("py");
     cmd.arg("map")
@@ -234,7 +234,98 @@ def celsius_to_fahrenheit(celsius):
         svec!["d", "7", "44.6"],
         svec!["e", "fib of 8", "incorrect input - not a float"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
+}
+
+#[test]
+fn py_map_userhelper_and_loadfile() {
+    let wrk = Workdir::new("py");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["letter", "number"],
+            svec!["a", "1"],
+            svec!["b", "2"],
+            svec!["c", "6"],
+            svec!["d", "7"],
+            svec!["e", "fib of 8"],
+        ],
+    );
+
+    wrk.create_from_string(
+        "user_helper.py",
+        r#"
+def fibonacci(input):
+    try:
+      float(input)
+    except ValueError:
+      return "incorrect input - not a number"
+    sinput = str(input)
+    if not float(sinput).is_integer():
+        return "incorrect input - not a whole number"
+
+    n = int(sinput)
+    if n < 0:
+        return "incorrect input - negative number"
+    elif n == 0:
+        return 0
+    elif n == 1 or n == 2:
+        return 1
+    else:
+        return fibonacci(n-1) + fibonacci(n-2)
+
+
+def celsius_to_fahrenheit(celsius):
+    try:
+        float(celsius)
+    except ValueError:
+        return "incorrect input - not a float"
+    fahrenheit = (float(celsius) * 9/5) + 32
+    return f'{fahrenheit:.1f}'
+"#,
+    );
+
+    wrk.create_from_string("testfile.py", "qsv_uh.fibonacci(number)");
+
+    let mut cmd = wrk.command("py");
+    cmd.arg("map")
+        .arg("--helper")
+        .arg("user_helper.py")
+        .arg("fib")
+        .arg("testfile.py")
+        .arg("data.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["letter", "number", "fib"],
+        svec!["a", "1", "1"],
+        svec!["b", "2", "1"],
+        svec!["c", "6", "8"],
+        svec!["d", "7", "13"],
+        svec!["e", "fib of 8", "incorrect input - not a number"],
+    ];
+    similar_asserts::assert_eq!(got, expected);
+
+    wrk.create_from_string("testfile2.code", "qsv_uh.celsius_to_fahrenheit(number)");
+
+    let mut cmd = wrk.command("py");
+    cmd.arg("map")
+        .arg("--helper")
+        .arg("user_helper.py")
+        .arg("fahrenheit")
+        .arg("file:testfile2.code")
+        .arg("data.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["letter", "number", "fahrenheit"],
+        svec!["a", "1", "33.8"],
+        svec!["b", "2", "35.6"],
+        svec!["c", "6", "42.8"],
+        svec!["d", "7", "44.6"],
+        svec!["e", "fib of 8", "incorrect input - not a float"],
+    ];
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -264,7 +355,7 @@ fn py_map_col_positional() {
         svec!["c", "72", "73"],
         svec!["d", "7", "8"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -294,7 +385,7 @@ fn py_map_col_by_key() {
         svec!["c", "72", "73"],
         svec!["d", "7", "8"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -324,7 +415,7 @@ fn py_map_col_by_attr() {
         svec!["c", "72", "73"],
         svec!["d", "7", "8"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -352,7 +443,7 @@ fn py_map_no_headers() {
         svec!["c", "72", "73"],
         svec!["d", "7", "8"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -382,7 +473,7 @@ fn py_map_boolean() {
         svec!["c", "72", "True"],
         svec!["d", "7", "False"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -407,7 +498,7 @@ fn py_filter() {
         svec!["b", "24"],
         svec!["c", "72"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -436,7 +527,7 @@ fn py_filter_error() {
         svec!["c", "72"],
         svec!["d", "7"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 
     wrk.assert_err(&mut cmd);
     let stderr_string = wrk.output_stderr(&mut cmd);
@@ -468,7 +559,7 @@ fn py_format() {
         svec!["10", "bananas", "20", "10 bananas cost $200.00"],
         svec!["3", "strawberries", "3.50", "3 strawberries cost $10.50"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -511,7 +602,7 @@ fn py_format_with_conditionals() {
             "3 strawberries cost $10.50. Its quite cheap!"
         ],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
 
 #[test]
@@ -542,5 +633,5 @@ fn py_format_header_with_invalid_chars() {
         svec!["10", "bananas", "20", "10 bananas cost $200.00"],
         svec!["3", "strawberries", "3.50", "3 strawberries cost $10.50"],
     ];
-    assert_eq!(got, expected);
+    similar_asserts::assert_eq!(got, expected);
 }
